from django import forms


class LocationPickerWidget(forms.TextInput):
    def render(self, name, value, attrs=None):
        if None == attrs:
            attrs = {}
        attrs['readonly'] = 'readonly'
        attrs['class'] = 'location_picker'
        return super(LocationPickerWidget, self).render(name, value, attrs)

    class Media:
        css = {
            'all': (
                '/static/css/location_picker.css',
            )
        }
        js = (
            'https://maps.googleapis.com/maps/api/js',
            '/static/js/location_picker.js',
        )



from django.db import models
from .widgets import LocationPickerWidget


class LocationField(models.CharField):
    def formfield(self, **kwargs):
        kwargs['widget'] = LocationPickerWidget
        return super(LocationField, self).formfield(**kwargs)


from setuptools import setup, find_packages


setup(
    name="django-location-picker",
    version='0.1.0',
    url="https://github.com/jamesfoley/django-location-picker",
    author="James Foley",
    author_email="jamesfoley@onespacemedia.com",
    platforms=["any"],
    packages=find_packages(),
    description='A location picker field for the Django admin',
    install_requires=[
        'django',
        'psycopg2',
        'django-suit',
        'django-optimizations',
        'Pillow',
        'django-reversion',
        'django-usertools',
        'django-historylinks',
        'django-watson',
        'django-extensions',
        'Werkzeug',
        'raven'
    ],
)
